LinuxPPC-Dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode
@ 2015-06-28 13:49 Maciej S. Szmigiero
  0 siblings, 0 replies; 5+ messages in thread
From: Maciej S. Szmigiero @ 2015-06-28 13:49 UTC (permalink / raw)
  To: alsa-devel@alsa-project.org
  Cc: Timur Tabi, Nicolin Chen, Xiubo Li, Liam Girdwood, Mark Brown,
	Jaroslav Kysela, Takashi Iwai, linuxppc-dev, linux-kernel,
	Fabio Estevam

Adjust set DAI format function in fsl_ssi driver so it
doesn't fail and clears RXDIR in AC'97 mode.

Signed-off-by: Maciej Szmigiero <mail@maciej.szmigiero.name>
---
 sound/soc/fsl/fsl_ssi.c |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
index e79dc16..d043c7c 100644
--- a/sound/soc/fsl/fsl_ssi.c
+++ b/sound/soc/fsl/fsl_ssi.c
@@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
 		scr &= ~CCSR_SSI_SCR_SYS_CLK_EN;
 		break;
 	default:
-		return -EINVAL;
+		if (!fsl_ssi_is_ac97(ssi_private))
+			return -EINVAL;
 	}
 
 	stcr |= strcr;
 	srcr |= strcr;
 
-	if (ssi_private->cpu_dai_drv.symmetric_rates) {
-		/* Need to clear RXDIR when using SYNC mode */
+	if (ssi_private->cpu_dai_drv.symmetric_rates
+		|| fsl_ssi_is_ac97(ssi_private)) {
+		/* Need to clear RXDIR when using SYNC or AC97 mode */
 		srcr &= ~CCSR_SSI_SRCR_RXDIR;
 		scr |= CCSR_SSI_SCR_SYN;
 	}

^ permalink raw reply related	[flat|nested] 5+ messages in thread

* [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode
@ 2015-07-30 14:35 Maciej S. Szmigiero
  2015-07-31  5:58 ` Markus Pargmann
  0 siblings, 1 reply; 5+ messages in thread
From: Maciej S. Szmigiero @ 2015-07-30 14:35 UTC (permalink / raw)
  To: alsa-devel@alsa-project.org
  Cc: Timur Tabi, Nicolin Chen, Xiubo Li, Liam Girdwood, Mark Brown,
	Jaroslav Kysela, Takashi Iwai, linuxppc-dev, linux-kernel,
	Fabio Estevam

Adjust set DAI format function in fsl_ssi driver so it
doesn't fail and clears RXDIR in AC'97 mode.

Signed-off-by: Maciej Szmigiero <mail@maciej.szmigiero.name>
---
 sound/soc/fsl/fsl_ssi.c |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
index 8e5ff5e..37aabe3 100644
--- a/sound/soc/fsl/fsl_ssi.c
+++ b/sound/soc/fsl/fsl_ssi.c
@@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
 		scr &= ~CCSR_SSI_SCR_SYS_CLK_EN;
 		break;
 	default:
-		return -EINVAL;
+		if (!fsl_ssi_is_ac97(ssi_private))
+			return -EINVAL;
 	}
 
 	stcr |= strcr;
 	srcr |= strcr;
 
-	if (ssi_private->cpu_dai_drv.symmetric_rates) {
-		/* Need to clear RXDIR when using SYNC mode */
+	if (ssi_private->cpu_dai_drv.symmetric_rates
+		|| fsl_ssi_is_ac97(ssi_private)) {
+		/* Need to clear RXDIR when using SYNC or AC97 mode */
 		srcr &= ~CCSR_SSI_SRCR_RXDIR;
 		scr |= CCSR_SSI_SCR_SYN;
 	}

^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode
  2015-07-30 14:35 Maciej S. Szmigiero
@ 2015-07-31  5:58 ` Markus Pargmann
  2015-07-31 15:13   ` Maciej S. Szmigiero
  0 siblings, 1 reply; 5+ messages in thread
From: Markus Pargmann @ 2015-07-31  5:58 UTC (permalink / raw)
  To: Maciej S. Szmigiero
  Cc: alsa-devel@alsa-project.org, Timur Tabi, Nicolin Chen, Xiubo Li,
	Liam Girdwood, Mark Brown, Jaroslav Kysela, Takashi Iwai,
	linuxppc-dev, linux-kernel, Fabio Estevam

[-- Attachment #1: Type: text/plain, Size: 2038 bytes --]

On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
> Adjust set DAI format function in fsl_ssi driver so it
> doesn't fail and clears RXDIR in AC'97 mode.
> 
> Signed-off-by: Maciej Szmigiero <mail@maciej.szmigiero.name>
> ---
>  sound/soc/fsl/fsl_ssi.c |    8 +++++---
>  1 files changed, 5 insertions(+), 3 deletions(-)
> 
> diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
> index 8e5ff5e..37aabe3 100644
> --- a/sound/soc/fsl/fsl_ssi.c
> +++ b/sound/soc/fsl/fsl_ssi.c
> @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
>  		scr &= ~CCSR_SSI_SCR_SYS_CLK_EN;
>  		break;
>  	default:
> -		return -EINVAL;
> +		if (!fsl_ssi_is_ac97(ssi_private))
> +			return -EINVAL;

I think it would be better to add another case for the other mode which
is supported (AC97) instead of using the default case.

>  	}
>  
>  	stcr |= strcr;
>  	srcr |= strcr;
>  
> -	if (ssi_private->cpu_dai_drv.symmetric_rates) {
> -		/* Need to clear RXDIR when using SYNC mode */
> +	if (ssi_private->cpu_dai_drv.symmetric_rates
> +		|| fsl_ssi_is_ac97(ssi_private)) {

Please fix this indention. Most of the driver is written with 2 tab
indention after a line break and the new policy seems to be to indent on
the opening bracket.

Regards,

Markus

> +		/* Need to clear RXDIR when using SYNC or AC97 mode */
>  		srcr &= ~CCSR_SSI_SRCR_RXDIR;
>  		scr |= CCSR_SSI_SCR_SYN;
>  	}
> 
> --
> To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
> the body of a message to majordomo@vger.kernel.org
> More majordomo info at  http://vger.kernel.org/majordomo-info.html
> Please read the FAQ at  http://www.tux.org/lkml/
> 

-- 
Pengutronix e.K.                           |                             |
Industrial Linux Solutions                 | http://www.pengutronix.de/  |
Peiner Str. 6-8, 31137 Hildesheim, Germany | Phone: +49-5121-206917-0    |
Amtsgericht Hildesheim, HRA 2686           | Fax:   +49-5121-206917-5555 |

[-- Attachment #2: Digital signature --]
[-- Type: application/pgp-signature, Size: 819 bytes --]

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode
  2015-07-31  5:58 ` Markus Pargmann
@ 2015-07-31 15:13   ` Maciej S. Szmigiero
  2015-08-02 18:51     ` Markus Pargmann
  0 siblings, 1 reply; 5+ messages in thread
From: Maciej S. Szmigiero @ 2015-07-31 15:13 UTC (permalink / raw)
  To: Markus Pargmann
  Cc: alsa-devel@alsa-project.org, Timur Tabi, Nicolin Chen, Xiubo Li,
	Liam Girdwood, Mark Brown, Jaroslav Kysela, Takashi Iwai,
	linuxppc-dev, linux-kernel, Fabio Estevam

On 31.07.2015 07:58, Markus Pargmann wrote:
> On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
>> Adjust set DAI format function in fsl_ssi driver so it
>> doesn't fail and clears RXDIR in AC'97 mode.
>>
>> Signed-off-by: Maciej Szmigiero <mail@maciej.szmigiero.name>
>> ---
>>  sound/soc/fsl/fsl_ssi.c |    8 +++++---
>>  1 files changed, 5 insertions(+), 3 deletions(-)
>>
>> diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
>> index 8e5ff5e..37aabe3 100644
>> --- a/sound/soc/fsl/fsl_ssi.c
>> +++ b/sound/soc/fsl/fsl_ssi.c
>> @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
>>  		scr &= ~CCSR_SSI_SCR_SYS_CLK_EN;
>>  		break;
>>  	default:
>> -		return -EINVAL;
>> +		if (!fsl_ssi_is_ac97(ssi_private))
>> +			return -EINVAL;
> 
> I think it would be better to add another case for the other mode which
> is supported (AC97) instead of using the default case.

This is a switch of DAI clock masters and AC'97 is none of them:
while "case 0:" can be added this would be very similar to the current code.

Alternatively, the whole switch statement could be wrapped inside
"if (!fsl_ssi_is_ac97(ssi_private))" if that would be better
with regards to code style.

>>  	}
>>  
>>  	stcr |= strcr;
>>  	srcr |= strcr;
>>  
>> -	if (ssi_private->cpu_dai_drv.symmetric_rates) {
>> -		/* Need to clear RXDIR when using SYNC mode */
>> +	if (ssi_private->cpu_dai_drv.symmetric_rates
>> +		|| fsl_ssi_is_ac97(ssi_private)) {
> 
> Please fix this indention. Most of the driver is written with 2 tab
> indention after a line break and the new policy seems to be to indent on
> the opening bracket.

Will reindent this.

> 
> Regards,
> 
> Markus

Best regards,
Maciej Szmigiero

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode
  2015-07-31 15:13   ` Maciej S. Szmigiero
@ 2015-08-02 18:51     ` Markus Pargmann
  0 siblings, 0 replies; 5+ messages in thread
From: Markus Pargmann @ 2015-08-02 18:51 UTC (permalink / raw)
  To: Maciej S. Szmigiero
  Cc: alsa-devel@alsa-project.org, Timur Tabi, Nicolin Chen, Xiubo Li,
	Liam Girdwood, Mark Brown, Jaroslav Kysela, Takashi Iwai,
	linuxppc-dev, linux-kernel, Fabio Estevam

[-- Attachment #1: Type: text/plain, Size: 2435 bytes --]

On Fri, Jul 31, 2015 at 05:13:06PM +0200, Maciej S. Szmigiero wrote:
> On 31.07.2015 07:58, Markus Pargmann wrote:
> > On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
> >> Adjust set DAI format function in fsl_ssi driver so it
> >> doesn't fail and clears RXDIR in AC'97 mode.
> >>
> >> Signed-off-by: Maciej Szmigiero <mail@maciej.szmigiero.name>
> >> ---
> >>  sound/soc/fsl/fsl_ssi.c |    8 +++++---
> >>  1 files changed, 5 insertions(+), 3 deletions(-)
> >>
> >> diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
> >> index 8e5ff5e..37aabe3 100644
> >> --- a/sound/soc/fsl/fsl_ssi.c
> >> +++ b/sound/soc/fsl/fsl_ssi.c
> >> @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
> >>  		scr &= ~CCSR_SSI_SCR_SYS_CLK_EN;
> >>  		break;
> >>  	default:
> >> -		return -EINVAL;
> >> +		if (!fsl_ssi_is_ac97(ssi_private))
> >> +			return -EINVAL;
> > 
> > I think it would be better to add another case for the other mode which
> > is supported (AC97) instead of using the default case.
> 
> This is a switch of DAI clock masters and AC'97 is none of them:
> while "case 0:" can be added this would be very similar to the current code.
> 
> Alternatively, the whole switch statement could be wrapped inside
> "if (!fsl_ssi_is_ac97(ssi_private))" if that would be better
> with regards to code style.

I looked at the wrong switch/case the DAIFMT_AC97 is actually used
but this patch is about the master clocks. It's fine then.

Thanks,

Markus

> 
> >>  	}
> >>  
> >>  	stcr |= strcr;
> >>  	srcr |= strcr;
> >>  
> >> -	if (ssi_private->cpu_dai_drv.symmetric_rates) {
> >> -		/* Need to clear RXDIR when using SYNC mode */
> >> +	if (ssi_private->cpu_dai_drv.symmetric_rates
> >> +		|| fsl_ssi_is_ac97(ssi_private)) {
> > 
> > Please fix this indention. Most of the driver is written with 2 tab
> > indention after a line break and the new policy seems to be to indent on
> > the opening bracket.
> 
> Will reindent this.
> 
> > 
> > Regards,
> > 
> > Markus
> 
> Best regards,
> Maciej Szmigiero
> 
> 

-- 
Pengutronix e.K.                           |                             |
Industrial Linux Solutions                 | http://www.pengutronix.de/  |
Peiner Str. 6-8, 31137 Hildesheim, Germany | Phone: +49-5121-206917-0    |
Amtsgericht Hildesheim, HRA 2686           | Fax:   +49-5121-206917-5555 |

[-- Attachment #2: Digital signature --]
[-- Type: application/pgp-signature, Size: 819 bytes --]

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2015-08-02 18:51 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-06-28 13:49 [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode Maciej S. Szmigiero
  -- strict thread matches above, loose matches on Subject: below --
2015-07-30 14:35 Maciej S. Szmigiero
2015-07-31  5:58 ` Markus Pargmann
2015-07-31 15:13   ` Maciej S. Szmigiero
2015-08-02 18:51     ` Markus Pargmann

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox